import { PostgresInstance } from "./utils/index.js";
import { PostgresInstanceOptions } from "../global.js";
interface PostgresObject {
    /**
     * Create a postgres instance.
     * @param id instance id. It should be unique.
     * @param options instance configuration options.
     */
    create(id?: string | null, options?: Partial<PostgresInstanceOptions> | null): Promise<PostgresInstance>;
    /**
     * Get a postgres instance.
     * @param id instance id.
     */
    get(id: string): PostgresInstance | undefined;
    /**
     * Delete a postgres instance.
     * @param id instance id.
     */
    delete(id: string): void;
    /**
     * Check if a postgres instance exist.
     * @param id instance id.
     */
    has(id: string): boolean;
    /**
     * Clear all postgres instances exist.
     */
    clear(): void;
    /**
     * Get all the postgres instances id.
     */
    ids(): string[];
    /**
     * Loop through all the postgres instances.
     */
    forEach(cb: (instance: PostgresInstance, id: string, postgres: PostgresObject) => void): void;
    /**
     * Get all the postgres instances.
     */
    instances(): PostgresInstance[];
    /**
     * Stop a postgres instance.
     * @param id instance id.
     */
    stop(id: string): Promise<void>;
    /**
     * Stop all postgres instances.
     */
    stopAll(): Promise<void>;
}
export declare const Postgres: PostgresObject;
export { PostgresInstance, generateId as generatePostgresInstanceID } from "./utils/index.js";
export { PostgresInstanceOptions } from "../global.js";
export { PostgresObject };
export default Postgres;
