var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import AsyncExitHook from "async-exit-hook";
import { generateId as generatePostgresInstanceID, PostgresInstance } from "./utils/index.js";
import { findFreePorts } from "find-free-ports";
;
const defaultsPostgresInstanceOptions = {
    port: 5432,
    databaseDir: "./data/db",
    user: "postgres",
    overwriteDatabaseDir: false,
    password: "password",
    initdbFlags: [],
    postgresFlags: [],
    persistent: true,
    createPostgresUser: false,
    onLog: console.log,
    onError: console.error,
};
const PostgresInstanceMap = new Map();
export const Postgres = {
    create(id, options) {
        return __awaiter(this, void 0, void 0, function* () {
            id = id || generatePostgresInstanceID();
            options = options || {};
            options = Object.assign(Object.assign(Object.assign({}, defaultsPostgresInstanceOptions), { port: (yield findFreePorts(1)).at(0) }), options);
            if (PostgresInstanceMap.has(id)) {
                throw new Error(`Instance key '${id}' already in use`);
            }
            let instance = new PostgresInstance(id, options);
            PostgresInstanceMap.set(id, instance);
            return instance;
        });
    },
    get(id) {
        return PostgresInstanceMap.get(id);
    },
    delete(id) {
        PostgresInstanceMap.delete(id);
    },
    has(id) {
        return PostgresInstanceMap.has(id);
    },
    clear() {
        PostgresInstanceMap.clear();
    },
    ids() {
        return Array.from(PostgresInstanceMap.keys());
    },
    forEach(cb) {
        PostgresInstanceMap.forEach((value, key) => cb(value, key, this));
    },
    instances() {
        return Array.from(PostgresInstanceMap.values());
    },
    stop(id) {
        return __awaiter(this, void 0, void 0, function* () {
            let postgresInstance = PostgresInstanceMap.get(id);
            if (postgresInstance) {
                yield postgresInstance.stop();
            }
        });
    },
    stopAll() {
        return __awaiter(this, void 0, void 0, function* () {
            yield Promise.all([...PostgresInstanceMap.values()].map((instance) => {
                instance.stop();
            }));
        });
    }
};
/**
 * This script should be called when a Node script is exited, so that we can
 * nicely shutdown all potentially started postgres instance, and we don't end up with
 * zombie processes.
 */
function gracefulShutdown(done) {
    return __awaiter(this, void 0, void 0, function* () {
        // Loop through all instances, stop them, and await the response
        yield Promise.all([...PostgresInstanceMap.values()].map((instance) => {
            return instance.stop();
        }));
        // Let NodeJS know we're done
        done();
    });
}
// Register graceful shutdown function
AsyncExitHook(gracefulShutdown);
export { PostgresInstance, generateId as generatePostgresInstanceID } from "./utils/index.js";
export default Postgres;
