import pg, { QueryResultRow } from "pg";
import { PostgresInstanceOptions } from "../../global.js";
export default class PostgresInstance {
    #private;
    constructor(id: string, options: PostgresInstanceOptions);
    /**
     * Start the Postgres instance. It is automatically
     * shut down when the script exits.
     */
    start(): Promise<void>;
    /**
     * Stop the postgres instance.
     */
    stop(): Promise<void>;
    /**
     * Initialize the postgres instance.
     */
    initialize(): Promise<void>;
    /**
     * Create a database with a given name on the postgres instance.
     */
    createDatabase(databaseName: string): Promise<void>;
    /**
     * Make a query on the postgres instance.
     */
    query<T extends QueryResultRow = any>(queryTextOrConfig: string, values?: any[]): Promise<pg.QueryResult<T>>;
    /**
     * Determine if database with a given name on the postgres instance exist.
     */
    hasDatabase(databaseName: string): Promise<boolean>;
    /**
     * Drop a database with a given name on the postgres instance.
     */
    dropDatabase(databaseName: string): Promise<void>;
    /**
     * Create a node postgres client using the existing postgres instance configuration.
     *
     * @param database The database that the postgres client should connect to
     * @param host The host that should be pre-filled in the connection options
     * @returns Client
     */
    client(database?: string, host?: string): pg.Client;
    /**
     * Get the postgres instance id.
     */
    get id(): string;
}
